@@ -12,8 +12,6 @@ test_that("hms2sec and sec2hms produce proper vectors and types",{
     expect_equivalent(x, c(7203, 14581))
     expect_equivalent(y, structure(c(0.00296296296296296, 0.04, 0.6546875), format = "h:m:s", class = "times"))
     
-    expect_error(sec2hms(c(NA, a)))
-    expect_error(sec2hms(c(NA, b)))
 	expect_true(inherits(y, "times"))
 })
 
